// @ts-check

import React from 'react'
import url from 'url'
import ReactDOM from 'react-dom/server'
import { BaseBody } from '../partials/base-body'
import { dateFilter, truncate, striptags } from '../utils'
import { renderToString } from '../render-to-string'

export default {
  type: 'template',
  ext: 'html',
  value: props => {
    const { metadata, canonicalURL, content } = props
    return renderToString(<Article {...props} />, {
      ...props,
      bodyClassName: 'type-article',
      prehead: (
        <>
          <meta property="og:type" content="article" />
          <meta
            property="article:published_time"
            content={dateFilter(metadata.published)}
          />
          {metadata.image && (
            <meta
              property="og:image"
              content={url.resolve(canonicalURL, metadata.image)}
            />
          )}
          <meta
            property="og:description"
            content={
              metadata.perex
                ? metadata.perex
                : metadata.perex_e
                ? truncate(metadata.perex_e)
                : content
                ? truncate(striptags(content))
                : undefined
            }
          />
        </>
      ),
      head: (
        <>
          <script
            type="text/x-mathjax-config"
            dangerouslySetInnerHTML={{
              __html: `
            MathJax.Hub.Config({
              extensions: ["tex2jax.js"],
              jax: ["input/TeX", "output/HTML-CSS"],
              tex2jax: {
                inlineMath: [ ['$','$'], ["\\\\(","\\\\)"] ],
                displayMath: [ ['$$','$$'], ["\\\\[","\\\\]"] ],
                processEscapes: true
              },
              elements: $("#content article"),
              "HTML-CSS": { availableFonts: ["TeX"] },
              locale: "cs",
              menuSettings: {
                zoom: "Hover"
              },
              MathEvents: {
                hover: 0
              }
            });`,
            }}
          />
          <script
            type="text/javascript"
            async
            src="https://cdn.mathjax.org/mathjax/latest/MathJax.js?config=TeX-AMS_CHTML&"
          ></script>
        </>
      ),
    })
  },
}

function Article({ metadata, content, config, file }) {
  return (
    <BaseBody config={config}>
      <div className="section container" id="content">
        <div className="row">&nbsp;</div>
        <div className="metadata">
          <h2 id="title">{metadata.title}</h2>
          {metadata.nodate ? null : (
            <a
              className="author"
              style={{ color: '#a2a2a2', display: 'block' }}
              target="_blank"
              href={`https://git.ok1kvk.cz/ok1kvk.cz/content/tree/master/content/articles/${file
                .replace('clanek/', '')
                .replace(/\/$/, '')}.md`}
            >
              {metadata.published ? (
                <>
                  <span style={{ color: '#626262' }}>
                    {dateFilter(metadata.published, 'D. M. YYYY')}
                  </span>
                  {metadata.author.gender === 'F' ? ' napsala ' : ' napsal '}
                  <span style={{ color: '#626262' }}>
                    {metadata.author.name}
                  </span>
                </>
              ) : (
                <>Článek nebyl publikován</>
              )}
            </a>
          )}
          <div className="tags">
            {metadata.tags.map(tag =>
              tag.url === 'tag/vse' ? null : (
                <React.Fragment key={tag.url}>
                  <a href={`${config.baseurl}/${tag.url}/1/`}>
                    <div className="chip">{tag.text}</div>
                  </a>{' '}
                </React.Fragment>
              ),
            )}
          </div>
        </div>
        <article>
          <p dangerouslySetInnerHTML={{ __html: content }} />
        </article>
      </div>
    </BaseBody>
  )
}
